/* folder_to_xml.h - file system to xml convertion for sciteproj
 *
 *  Copyright 2009 Andreas Ronnquist
 *
 * This file is part of Sciteproj.
 * 
 * Sciteproj is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sciteproj is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Sciteproj.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef __FOLDER_TO_XML_HEADER_
#define __FOLDER_TO_XML_HEADER_

gboolean folder_to_xml(gchar *folder,gchar *save_filename,int max_depth);


#endif /*__FOLDER_TO_XML_HEADER_*/
